@@ -26,6 +26,7 @@ import pyutilib.component.core
 from coopr.opt.base import *
 from coopr.opt import SolverResults, TerminationCondition, SolutionStatus, Solution, ProblemSense
 import coopr.openopt.func_designer
+import sys
 
 
 class OpenOptSolver(OptSolver):
@@ -64,21 +65,21 @@ class OpenOptSolver(OptSolver):
         if self.problem is not None:
             return (self.problem,ProblemFormat.colin_optproblem,None)
         self._instance = args[0]
-        self.problem = func_designer.Pyomo2FuncDesigner(args[0])
+        self.problem = coopr.openopt.func_designer.Pyomo2FuncDesigner(args[0])
         return (self.problem, ProblemFormat.FuncDesigner, None)
 
     def _presolve(self, *args, **kwds):
         try:
-            if self.options.solver is None:
+            if self.options.subsolver is None:
                 raise pyutilib.component.config.OptionError('ERROR')
-            pyutilib.services.register_executable(self.options.solver)
+            pyutilib.services.register_executable(self.options.subsolver)
         except pyutilib.component.config.OptionError:
             raise ValueError("No solver option specified for OpenOpt solver interface")
         OptSolver._presolve(self, *args, **kwds)
 
     def _apply_solver(self):
         try:
-            self._ans = self.problem.minimize(self.problem.f, self.problem.initial_point, solver=self.options.solver)
+            self._ans = self.problem.minimize(self.problem.f, self.problem.initial_point, solver=self.options.subsolver)
         except openopt.OpenOptException:
             e = sys.exc_info()[1]
             raise RuntimeError(str(e))
@@ -95,7 +96,7 @@ class OpenOptSolver(OptSolver):
         #print self._ans.xf
 
         solv = results.solver
-        solv.name = self.options.solver
+        solv.name = self.options.subsolver
         #solv.status = self._glpk_get_solver_status()
         #solv.memory_used = "%d bytes, (%d KiB)" % (peak_mem, peak_mem/1024)
         solv.wallclock_time = self._ans.elapsed['solver_time']
